bloc_suite
library
Classes
BlocEventTransformer <E >
A utility class providing various event transformers for Bloc pattern.
BlocSelectorWidget <B extends StateStreamableSource<S > , S , T >
A specialized widget that optimizes rebuilds by selecting specific parts of a Bloc's state.
Combines the functionality of BlocBuilder with selective state updates.
BlocWidget <B extends StateStreamableSource<S > , S >
Base class for widgets that build themselves based on interaction with
a specified bloc.
EventWrapper <T >
A wrapper that holds an event along with its lifecycle status and error (if any).
FlutterBlocObserver
A BlocObserver that provides detailed logging capabilities for Flutter Bloc events
and state changes with customizable filtering options.
LifecycleBloc <Event , State >
LifecycleBloc 🏗️
ReplayBloc <Event extends ReplayEvent , State >
A specialized Bloc which supports undo and redo operations.
ReplayCubit <State >
A specialized Cubit which supports undo and redo operations.
ReplayEvent
Base event class for all ReplayBloc events.
Enums
EventStatus
Represents the lifecycle status of an event.
Mixins
ReplayBlocMixin <Event extends ReplayEvent , State >
A mixin which enables undo and redo operations
for Bloc classes.
ReplayCubitMixin <State >
A mixin which enables undo and redo operations
for Cubit classes.